@@ -24,6 +24,7 @@ import utils
 
 LOGGER = logging.getLogger(__name__)
 
+
 class Request(urllib2.Request):
     """
     Extends the urllib2.Request to support all HTTP request types.
@@ -135,7 +136,7 @@ class RemoteConnection(object):
                 if parsed_url.username:
                     auth = parsed_url.username
                     if parsed_url.password:
-                      auth += ':%s' % parsed_url.password
+                        auth += ':%s' % parsed_url.password
                     netloc = '%s@%s' % (auth, netloc)
                 remote_server_addr = urlparse.urlunparse(
                     (parsed_url.scheme, netloc, parsed_url.path,
@@ -222,13 +223,11 @@ class RemoteConnection(object):
             Command.SET_SPEED: ('POST', '/session/$sessionId/speed'),
             Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY:
                 ('GET',  '/session/$sessionId/element/$id/css/$propertyName'),
-            Command.IMPLICIT_WAIT: 
+            Command.IMPLICIT_WAIT:
                 ('POST', '/session/$sessionId/timeouts/implicit_wait'),
             Command.EXECUTE_ASYNC_SCRIPT: ('POST','/session/$sessionId/execute_async'),
             Command.SET_SCRIPT_TIMEOUT:
                 ('POST', '/session/$sessionId/timeouts/async_script'),
-            Command.GET_ELEMENT_VALUE_OF_CSS_PROPERTY:
-                ('GET', '/session/$sessionId/element/$id/css/$propertyName'),
             Command.SET_TIMEOUTS:
                 ('POST', '/session/$sessionId/timeouts'),
             Command.DISMISS_ALERT:
@@ -263,6 +262,62 @@ class RemoteConnection(object):
                 ('POST', '/session/$sessionId/orientation'),
             Command.GET_SCREEN_ORIENTATION:
                 ('GET', '/session/$sessionId/orientation'),
+            Command.SINGLE_TAP:
+                ('POST', '/session/$sessionId/touch/click'),
+            Command.TOUCH_DOWN:
+                ('POST', '/session/$sessionId/touch/down'),
+            Command.TOUCH_UP:
+                ('POST', '/session/$sessionId/touch/up'),
+            Command.TOUCH_MOVE:
+                ('POST', '/session/$sessionId/touch/move'),
+            Command.TOUCH_SCROLL:
+                ('POST', '/session/$sessionId/touch/scroll'),
+            Command.DOUBLE_TAP:
+                ('POST', '/session/$sessionId/touch/doubleclick'),
+            Command.LONG_PRESS:
+                ('POST', '/session/$sessionId/touch/longclick'),
+            Command.FLICK:
+                ('POST', '/session/$sessionId/touch/flick'),
+            Command.EXECUTE_SQL:
+                ('POST', '/session/$sessionId/execute_sql'),
+            Command.GET_LOCATION:
+                ('GET', '/session/$sessionId/location'),
+            Command.SET_LOCATION:
+                ('POST', '/session/$sessionId/location'),
+            Command.GET_APP_CACHE:
+                ('GET', '/session/$sessionId/application_cache'),
+            Command.GET_APP_CACHE_STATUS:
+                ('GET', '/session/$sessionId/application_cache/status'),
+            Command.CLEAR_APP_CACHE:
+                ('DELETE', '/session/$sessionId/application_cache/clear'),
+            Command.IS_BROWSER_ONLINE:
+                ('GET', '/session/$sessionId/browser_connection'),
+            Command.SET_BROWSER_ONLINE:
+                ('POST', '/session/$sessionId/browser_connection'),
+            Command.GET_LOCAL_STORAGE_ITEM:
+                ('GET', '/session/$sessionId/local_storage/key/$key'),
+            Command.REMOVE_LOCAL_STORAGE_ITEM:
+                ('POST', '/session/$sessionId/local_storage/key/$key'),
+            Command.GET_LOCAL_STORAGE_KEYS:
+                ('GET', '/session/$sessionId/local_storage'),
+            Command.SET_LOCAL_STORAGE_ITEM:
+                ('POST', '/session/$sessionId/local_storage'),
+            Command.CLEAR_LOCAL_STORAGE:
+                ('DELETE', '/session/$sessionId/local_storage'),
+            Command.GET_LOCAL_STORAGE_SIZE:
+                ('GET', '/session/$sessionId/local_storage/size'),
+            Command.GET_SESSION_STORAGE_ITEM:
+                ('GET', '/session/$sessionId/session_storage/key/$key'),
+            Command.REMOVE_SESSION_STORAGE_ITEM:
+                ('DELETE', '/session/$sessionId/session_storage/key/$key'),
+            Command.GET_SESSION_STORAGE_KEYS:
+                ('GET', '/session/$sessionId/session_storage'),
+            Command.SET_SESSION_STORAGE_ITEM:
+                ('POST', '/session/$sessionId/session_storage'),
+            Command.CLEAR_SESSION_STORAGE:
+                ('DELETE', '/session/$sessionId/session_storage'),
+            Command.GET_SESSION_STORAGE_SIZE:
+                ('GET','/session/$sessionId/session_storage/size'),
             }
 
     def execute(self, command, params):
@@ -299,22 +354,28 @@ class RemoteConnection(object):
         LOGGER.debug('%s %s %s' % (method, url, data))
 
         parsed_url = urlparse.urlparse(url)
-        auth = None
         password_manager = None
         if parsed_url.username:
             netloc = parsed_url.hostname
             if parsed_url.port:
                 netloc += ":%s" % parsed_url.port
-            cleaned_url = urlparse.urlunparse((parsed_url.scheme, netloc, parsed_url.path,
-                parsed_url.params, parsed_url.query, parsed_url.fragment))
+            cleaned_url = urlparse.urlunparse((parsed_url.scheme,
+                                               netloc,
+                                               parsed_url.path,
+                                               parsed_url.params,
+                                               parsed_url.query,
+                                               parsed_url.fragment))
             password_manager = urllib2.HTTPPasswordMgrWithDefaultRealm()
-            password_manager.add_password(None, "%s://%s" % (parsed_url.scheme, netloc), parsed_url.username, parsed_url.password)
+            password_manager.add_password(None,
+                                          "%s://%s" % (parsed_url.scheme, netloc),
+                                          parsed_url.username,
+                                          parsed_url.password)
             request = Request(cleaned_url, data=data, method=method)
         else:
             request = Request(url, data=data, method=method)
 
-
         request.add_header('Accept', 'application/json')
+        request.add_header('Content-Type', 'application/json;charset=UTF-8')
 
         if password_manager:
             opener = urllib2.build_opener(urllib2.HTTPRedirectHandler(),
